/**
 * Instrumentation Vuze Plugin
 * 
 * Copyright 2008, Yale Laboratory of Networked Systems
 */

package net.yale.cs.p4p.p2p.azureus.log.listeners;

import java.util.HashMap;
import java.util.Map;

import net.yale.cs.p4p.p2p.azureus.log.XFerLogPlugin;

import org.gudy.azureus2.plugins.download.Download;
import org.gudy.azureus2.plugins.download.DownloadException;
import org.gudy.azureus2.plugins.download.DownloadPeerListener;
import org.gudy.azureus2.plugins.peers.PeerManager;

public class XFerDownloadPeerListener implements DownloadPeerListener {
	
	private XFerLogPlugin plugin_;
	private Map<PeerManager, XFerPeerManagerListener> listeners_ = new HashMap<PeerManager, XFerPeerManagerListener>();

	public XFerDownloadPeerListener(XFerLogPlugin plugin) {
		plugin_ = plugin;

		/* Add listeners for existing downloads */
		for (Download download : plugin_.getPluginInterface().getDownloadManager().getDownloads()) {
			if (download.getPeerManager() != null) {
				plugin_.getLogger().log("Listening on existing download " + download.getName());
				peerManagerAdded(download, download.getPeerManager());
			}
		}
	}

	public void peerManagerAdded(Download download, PeerManager peer_manager) {
		if (!listeners_.containsKey(peer_manager)) {
			XFerPeerManagerListener l = new XFerPeerManagerListener(plugin_);
			listeners_.put(peer_manager, l);
			peer_manager.addListener(l);
		}
	}

	public void peerManagerRemoved(Download download, PeerManager peer_manager) {
		XFerPeerManagerListener l = listeners_.remove(peer_manager);
		if (l != null) {
			l.cleanup();
			peer_manager.removeListener(l);
		}
	}

	public void cleanup() {
		while (!listeners_.keySet().isEmpty()) {
			PeerManager peerManager = listeners_.keySet().iterator().next();
			try {
				peerManagerRemoved(peerManager.getDownload(), peerManager);
			} catch (DownloadException e) { /* Ignore */ }
		}
	}

}
