/**
 * Instrumentation Vuze Plugin
 * 
 * Copyright 2008, Yale Laboratory of Networked Systems
 */

package net.yale.cs.p4p.p2p.azureus.log.listeners;

import java.util.HashMap;
import java.util.Map;

import net.yale.cs.p4p.p2p.azureus.log.XFerLogPlugin;

import org.gudy.azureus2.plugins.peers.Peer;
import org.gudy.azureus2.plugins.peers.PeerManager;
import org.gudy.azureus2.plugins.peers.PeerManagerListener;

public class XFerPeerManagerListener implements PeerManagerListener {
	
	private XFerLogPlugin plugin_;
	private Map<Peer, XFerPeerListener> listeners_ = new HashMap<Peer, XFerPeerListener>();

	public XFerPeerManagerListener(XFerLogPlugin plugin) {
		plugin_ = plugin;
	}

	public void peerAdded(PeerManager manager, Peer peer) {
		if (!listeners_.containsKey(peer)) {
			XFerPeerListener l = new XFerPeerListener(plugin_, peer);
			listeners_.put(peer, l);
			peer.addListener(l);
		}
	}

	public void peerRemoved(PeerManager manager, Peer peer) {
		XFerPeerListener l = listeners_.remove(peer);
		if (l != null) {
			l.cleanup();
			peer.removeListener(l);
		}
	}

	public void cleanup() {
		while (!listeners_.keySet().isEmpty()) {
			Peer peer = listeners_.keySet().iterator().next();
			peerRemoved(peer.getManager(), peer);
		}
	}
}
