/**
 * Instrumentation Vuze Plugin
 * 
 * Copyright 2008, Yale Laboratory of Networked Systems
 */

package net.yale.cs.p4p.p2p.azureus.log.records;

import java.io.IOException;
import java.net.HttpURLConnection;
import java.net.MalformedURLException;
import java.net.URL;
import java.net.URLConnection;

import net.yale.cs.p4p.p2p.azureus.log.XFerLogPlugin;

public class RemoteLoggingCheck
{
	private XFerLogPlugin plugin_;
	private long lastCheckTime_ = 0;

	private boolean enabled_ = true;
	public boolean isEnabled() { return enabled_; }

	public RemoteLoggingCheck(XFerLogPlugin plugin) {
		plugin_ = plugin;
	}

	public void doUpdateEnabled() {

		/* If not time to update yet, exit early */
		if (System.currentTimeMillis() - lastCheckTime_ < plugin_.getConfig().getCfgPortalDBInterval() * 1000)
			return;

		lastCheckTime_ = System.currentTimeMillis();
		
		/* Get a connection to the server */
		plugin_.getLogger().log("checking remote server for updated logging status");
		HttpURLConnection conn;
		try {
			URL url = plugin_.getConfig().getCfgPortalDBURL();
			
			URLConnection urlConn = url.openConnection();
			if (!(urlConn instanceof HttpURLConnection))
				throw new MalformedURLException("HTTP URL Required");

			conn = (HttpURLConnection)urlConn;
		} catch (IOException e) {
			plugin_.getLogger().log("failed to create connection to Portal Database server:" + e);
			enabled_ = false;
			return;
		}

		conn.setConnectTimeout(plugin_.getConfig().getCfgConnectTimeout() * 1000);
		conn.setReadTimeout(plugin_.getConfig().getCfgReadTimeout() * 1000);

		try {
			/* Be sure we've got a valid response code */
			if (conn.getResponseCode() != HttpURLConnection.HTTP_OK) {
				plugin_.getLogger().log("remote site returned error; disabling logging");
				enabled_ = false;
				return;
			}

			/* Everything went okay */
			plugin_.getLogger().log("remote site says logging should be enabled");
			enabled_ = true;
			return;
		} catch (IOException e) {
			plugin_.getLogger().log("failed to query Portal Database server: " + e);
			enabled_ = false;
			return;
		} finally {
			conn.disconnect();
		}

	}

}
